==> apache-dolphinscheduler-3.0.6-src.tar.gz: apache-dolphinscheduler-3.0.6-src/dolphinscheduler-master/src/main/java/org/apache/dolphinscheduler/server/master/dispatch/executor/ExecutorManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.server.master.dispatch.executor;

import org.apache.dolphinscheduler.server.master.dispatch.context.ExecutionContext;
import org.apache.dolphinscheduler.server.master.dispatch.exceptions.ExecuteException;

/**
 *  executor manager
 */
public interface ExecutorManager<T> {

    /**
     * before execute
     *
     * @param executeContext executeContext
     * @throws ExecuteException if error throws ExecuteException
     */
    void beforeExecute(ExecutionContext executeContext) throws ExecuteException;

    /**
     * execute task
     * @param context context
     * @return T
     * @throws ExecuteException if error throws ExecuteException
     */
    T execute(ExecutionContext context) throws ExecuteException;

    /**
     * execute task directly without retry
     * @param context context
     * @throws ExecuteException if error throws ExecuteException
     */
    void executeDirectly(ExecutionContext context) throws ExecuteException;

    /**
     *  after execute
     * @param context context
     * @throws ExecuteException if error throws ExecuteException
     */
    void afterExecute(ExecutionContext context) throws ExecuteException;
}

==> apache-dolphinscheduler-3.2.0-src.tar.gz: apache-dolphinscheduler-3.2.0-src/dolphinscheduler-master/src/main/java/org/apache/dolphinscheduler/server/master/dispatch/executor/ExecutorManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.server.master.dispatch.executor;

import org.apache.dolphinscheduler.server.master.dispatch.context.ExecutionContext;
import org.apache.dolphinscheduler.server.master.dispatch.exceptions.ExecuteException;

/**
 *  executor manager
 */
public interface ExecutorManager<T> {

    /**
     * before execute
     *
     * @param executeContext executeContext
     * @throws ExecuteException if error throws ExecuteException
     */
    void beforeExecute(ExecutionContext executeContext) throws ExecuteException;

    /**
     * execute task
     *
     * @param context context
     * @return T
     * @throws ExecuteException if error throws ExecuteException
     */
    void execute(ExecutionContext context) throws ExecuteException;

    /**
     * execute task directly without retry
     * @param context context
     * @throws ExecuteException if error throws ExecuteException
     */
    void executeDirectly(ExecutionContext context) throws ExecuteException;

    /**
     *  after execute
     * @param context context
     * @throws ExecuteException if error throws ExecuteException
     */
    void afterExecute(ExecutionContext context) throws ExecuteException;
}
